@@ -7,27 +7,22 @@ Usage::
     from boto3.session import Session
     from mypy_boto3_emr_serverless import (
         Client,
-        EMRServerlessWebServiceClient,
+        EMRServerlessClient,
         ListApplicationsPaginator,
         ListJobRunsPaginator,
     )
 
     session = Session()
-    client: EMRServerlessWebServiceClient = session.client("emr-serverless")
+    client: EMRServerlessClient = session.client("emr-serverless")
 
     list_applications_paginator: ListApplicationsPaginator = client.get_paginator("list_applications")
     list_job_runs_paginator: ListJobRunsPaginator = client.get_paginator("list_job_runs")
     ```
 """
-from .client import EMRServerlessWebServiceClient
+from .client import EMRServerlessClient
 from .paginator import ListApplicationsPaginator, ListJobRunsPaginator
 
-Client = EMRServerlessWebServiceClient
+Client = EMRServerlessClient
 
 
-__all__ = (
-    "Client",
-    "EMRServerlessWebServiceClient",
-    "ListApplicationsPaginator",
-    "ListJobRunsPaginator",
-)
+__all__ = ("Client", "EMRServerlessClient", "ListApplicationsPaginator", "ListJobRunsPaginator")
